#!/bin/sh
version=11.1.0
libversion=0.0.0
bindir=/usr/bin
mandir=/usr/man
awkcmd=awk
osname=`uname -s`
userid=`id -u`
setupdir=`dirname $0`
setupdir=`cd "$setupdir" && pwd`

if [ "$osname" = "OS400" ]; then
   bindir=/QOpenSys/usr/bin
   mandir=/QOpenSys/usr/man
   if test -z "$1" ; then
      installdir=/QOpenSys/usr/local
   else
      installdir="/QOpenSys/$1"
   fi
elif test -z "$1" ; then
   installdir=/usr/local
else
   installdir="$1"
   if [ "$userid" != "0" ]
   then
      bindir="$installdir/bin"
      mandir=
   fi
fi
umask 022
cd $setupdir/usr/local
logfile=$installdir/share/tbarcode11/install.log

CheckFiles()
{
  if test ! -d include
  then
    echo "Error: Could not find directory 'include'!"
    return 1;
  fi
   
  if test ! -d lib
  then
    echo "Error: Could not find directory 'lib'!"
    return 1;
  fi
  
  if test ! -d share
  then
    echo "Error: Could not find directory 'share'!"
    return 1;
  fi
  
  return 0;
}

createFolder()
{
  FOLDER="$1"
  if test ! -d "$FOLDER"
  then
	mkdir -p "$FOLDER"
  fi
}	

createLink()
{
	echo "$2 # link to $1" >> $logfile
	ln -sf $1 $2 2> /dev/null
}
InstallFiles()
{
  createFolder $installdir

  echo "Copying tbarcode files..."
  cp -R share $installdir  
  echo "# Installation log (" `date` ")" >> $logfile
  find share -type f | $awkcmd -v DIR=$installdir '{ print DIR "/" $1 }' >> $logfile

  echo "Copying include files..."
  cp -R include $installdir
  find include -type f | $awkcmd -v DIR=$installdir '{ print DIR "/" $1 }' >> $logfile

  echo "Copying libraries..."
  cp -R lib $installdir
  find lib -type f | $awkcmd -v DIR=$installdir '{ print DIR "/" $1 }' >> $logfile
}

PostInstallationProcedure()
{
	if test -f $installdir/lib/libtbarcode11.so.$libversion
	then
		echo "Registering TBarCode Library..."
		createLink $installdir/lib/libtbarcode11.so.$libversion $installdir/lib/libtbarcode11.so.0
		createLink $installdir/lib/libtbarcode11.so.$libversion $installdir/lib/libtbarcode11.so
	fi
  
  echo "Creating link for TBarCode executable..."
  createFolder $bindir
  if  test -f  /usr/local/share/tbarcode11/tbarcode
  then
	createLink $installdir/share/tbarcode11/tbarcode $bindir/tbarcode
  else
	cat > $bindir/tbarcode <<EOF
#!/bin/sh
LD_LIBRARY_PATH=$installdir/lib $installdir/share/tbarcode11/tbarcode "\$@"
EOF
	chmod a+x $bindir/tbarcode

	echo "Updating printer scrits..."
	for FILE in `find share -name filter*`
	do
		sed -e "s#/usr/local/share/tbarcode11#$bindir#g" $FILE > $installdir/$FILE
	done
  fi

  if [ "$mandir" != "" ]
  then
	  echo "Creating link for TBarCode manual..."
	  createLink $installdir/share/tbarcode11/tbarcode.1 $mandir/man1
	  if test $? -ne 0
	  then
	    echo "Warning: Could not create link to tbarcode manual in $mandir !"
	  fi
  fi

	if test -e /usr/sbin/lpfilter
	then
		echo "Registering TBarCode printing filters in LP print service..."
		/usr/sbin/lpfilter -f tbarcode_ps -F $installdir/share/tbarcode11/filterlp_ps.fd
		/usr/sbin/lpfilter -f tbarcode_pcl -F $installdir/share/tbarcode11/filterlp_pcl.fd
	fi

	if test -d /usr/lib/cups/filter
	then
		echo "Registering TBarCode printing filters in CUPS print service..."
		createLink $installdir/share/tbarcode11/filtercups_pcl.sh /usr/lib/cups/filter/filtercups_pcl.sh
		createLink $installdir/share/tbarcode11/filtercups_ps.sh  /usr/lib/cups/filter/filtercups_ps.sh
	fi

  echo "Setting file permissions..."
  chmod a+r $installdir/share/tbarcode11/*
  chmod a+x $installdir/share/tbarcode11/*.sh
  chmod a+x $installdir/share/tbarcode11/tbarcode
  if test $? -ne 0
  then
    echo "Error: chmod failed!"
    return 1;
  fi
  return 0;
}

LICENSE_FILE="$setupdir/tecit_license_agreement.txt"

echo " TBarCode for $osname - Installation"
echo " -----------------------------------"
echo ""

# Display license agreeement
if test -f "$LICENSE_FILE"
  then
  cat "$LICENSE_FILE" | more
  agreed=""
  while [ -z "$agreed" ]; do
    echo ""
    echo "Do you agree to the above license terms? [yes or no]"
    read reply leftover
    case $reply in
      [yY] | [yY][eE][sS])
         agreed=1
         ;;
      [nN] | [nN][oO])
         echo "If you don't agree to the license you can't install this software"
         exit 1
         ;;
     esac
   done
else
  echo "License agreement $LICENSE_FILE not found!"
  exit 1;
fi

if CheckFiles && InstallFiles && PostInstallationProcedure
then    
  echo "Installation finished."
  echo "Do you want to print a test case using the newly installed TBarCodeX? [y or n]"
  read reply
  case $reply in
    [yY] | [yY][eE][sS])
      $bindir/tbarcode --output=barcode.eps --barcode=20 --data="abc1234"
      ;;
  esac
  exit 0
else
  echo "Installation aborted."
  exit 1
fi

